@@ -23,6 +23,7 @@ class FacebookOAuth2(BaseOAuth2):
     ACCESS_TOKEN_URL = 'https://graph.facebook.com/oauth/access_token'
     REVOKE_TOKEN_URL = 'https://graph.facebook.com/{uid}/permissions'
     REVOKE_TOKEN_METHOD = 'DELETE'
+    USER_DATA_URL = 'https://graph.facebook.com/me'
     EXTRA_DATA = [
         ('id', 'id'),
         ('expires', 'expires')
@@ -30,18 +31,22 @@ class FacebookOAuth2(BaseOAuth2):
 
     def get_user_details(self, response):
         """Return user details from Facebook account"""
+        fullname, first_name, last_name = self.get_user_names(
+            response.get('name', ''),
+            response.get('first_name', ''),
+            response.get('last_name', '')
+        )
         return {'username': response.get('username', response.get('name')),
                 'email': response.get('email', ''),
-                'fullname': response.get('name', ''),
-                'first_name': response.get('first_name', ''),
-                'last_name': response.get('last_name', '')}
+                'fullname': fullname,
+                'first_name': first_name,
+                'last_name': last_name}
 
     def user_data(self, access_token, *args, **kwargs):
         """Loads user data from service"""
         params = self.setting('PROFILE_EXTRA_PARAMS', {})
         params['access_token'] = access_token
-        return self.get_json('https://graph.facebook.com/me',
-                             params=params)
+        return self.get_json(self.USER_DATA_URL, params=params)
 
     def process_error(self, data):
         super(FacebookOAuth2, self).process_error(data)
@@ -174,3 +179,15 @@ class FacebookAppOAuth2(FacebookOAuth2):
             if constant_time_compare(sig, expected_sig) and \
                data['issued_at'] > (time.time() - 86400):
                 return data
+
+
+class Facebook2OAuth2(FacebookOAuth2):
+    """Facebook OAuth2 authentication backend using Facebook Open Graph 2.0"""
+    AUTHORIZATION_URL = 'https://www.facebook.com/v2.0/dialog/oauth'
+    ACCESS_TOKEN_URL = 'https://graph.facebook.com/v2.0/oauth/access_token'
+    REVOKE_TOKEN_URL = 'https://graph.facebook.com/v2.0/{uid}/permissions'
+    USER_DATA_URL = 'https://graph.facebook.com/v2.0/me'
+
+
+class Facebook2AppOAuth2(Facebook2OAuth2, FacebookAppOAuth2):
+    pass
