@@ -8,9 +8,9 @@ from social.backends.oauth import BaseOAuth1
 class FlickrOAuth(BaseOAuth1):
     """Flickr OAuth authentication backend"""
     name = 'flickr'
-    AUTHORIZATION_URL = 'http://www.flickr.com/services/oauth/authorize'
-    REQUEST_TOKEN_URL = 'http://www.flickr.com/services/oauth/request_token'
-    ACCESS_TOKEN_URL = 'http://www.flickr.com/services/oauth/access_token'
+    AUTHORIZATION_URL = 'https://www.flickr.com/services/oauth/authorize'
+    REQUEST_TOKEN_URL = 'https://www.flickr.com/services/oauth/request_token'
+    ACCESS_TOKEN_URL = 'https://www.flickr.com/services/oauth/access_token'
     EXTRA_DATA = [
         ('id', 'id'),
         ('username', 'username'),
@@ -19,9 +19,14 @@ class FlickrOAuth(BaseOAuth1):
 
     def get_user_details(self, response):
         """Return user details from Flickr account"""
+        fullname, first_name, last_name = self.get_user_names(
+            response.get('fullname')
+        )
         return {'username': response.get('username') or response.get('id'),
                 'email': '',
-                'first_name': response.get('fullname')}
+                'fullname': fullname,
+                'first_name': first_name,
+                'last_name': last_name}
 
     def user_data(self, access_token, *args, **kwargs):
         """Loads user data from service"""
