@@ -26,10 +26,15 @@ class LiveOAuth2(BaseOAuth2):
 
     def get_user_details(self, response):
         """Return user details from Live Connect account"""
+        fullname, first_name, last_name = self.get_user_names(
+            first_name=response.get('first_name'),
+            last_name=response.get('last_name')
+        )
         return {'username': response.get('name'),
                 'email': response.get('emails', {}).get('account', ''),
-                'first_name': response.get('first_name'),
-                'last_name': response.get('last_name')}
+                'fullname': fullname,
+                'first_name': first_name,
+                'last_name': last_name}
 
     def user_data(self, access_token, *args, **kwargs):
         """Loads user data from service"""
