@@ -10,6 +10,11 @@ class StravaOAuth(BaseOAuth2):
     AUTHORIZATION_URL = 'https://www.strava.com/oauth/authorize'
     ACCESS_TOKEN_URL = 'https://www.strava.com/oauth/token'
     ACCESS_TOKEN_METHOD = 'POST'
+    # Strava doesn't check for parameters in redirect_uri and directly appends
+    # the auth parameters to it, ending with an URL like:
+    # http://example.com/complete/strava?redirect_state=xxx?code=xxx&state=xxx
+    # Check issue #259 for details.
+    REDIRECT_STATE = False
 
     def get_user_id(self, details, response):
         return response['athlete']['id']
@@ -18,10 +23,15 @@ class StravaOAuth(BaseOAuth2):
         """Return user details from Strava account"""
         # because there is no usernames on strava
         username = response['athlete']['id']
-        first_name = response['athlete'].get('first_name', '')
         email = response['athlete'].get('email', '')
+        fullname, first_name, last_name = self.get_user_names(
+            first_name=response['athlete'].get('firstname', ''),
+            last_name=response['athlete'].get('lastname', ''),
+        )
         return {'username': str(username),
+                'fullname': fullname,
                 'first_name': first_name,
+                'last_name': last_name,
                 'email': email}
 
     def user_data(self, access_token, *args, **kwargs):
