@@ -31,8 +31,13 @@ class WeiboOAuth2(BaseOAuth2):
             username = response.get('domain', '')
         else:
             username = response.get('name', '')
+        fullname, first_name, last_name = self.get_user_names(
+            first_name=response.get('screen_name', '')
+        )
         return {'username': username,
-                'first_name': response.get('screen_name', '')}
+                'fullname': fullname,
+                'first_name': first_name,
+                'last_name': last_name}
 
     def user_data(self, access_token, *args, **kwargs):
         return self.get_json('https://api.weibo.com/2/users/show.json',
