@@ -25,7 +25,7 @@ class UserMixin(object):
     def get_backend(self, strategy=None):
         strategy = strategy or get_current_strategy()
         if strategy:
-            return get_backend(strategy.backends, self.provider)
+            return get_backend(strategy.get_backends(), self.provider)
 
     def get_backend_instance(self, strategy=None):
         strategy = strategy or get_current_strategy()
@@ -87,6 +87,11 @@ class UserMixin(object):
                 self.extra_data = extra_data
             return True
 
+    @classmethod
+    def clean_username(cls, value):
+        """Clean username removing any unsupported character"""
+        return CLEAN_USERNAME_REGEX.sub('', value)
+
     @classmethod
     def changed(cls, user):
         """The given user instance is ready to be saved"""
@@ -107,10 +112,6 @@ class UserMixin(object):
         """Return the max length for username"""
         raise NotImplementedError('Implement in subclass')
 
-    @classmethod
-    def clean_username(cls, value):
-        return CLEAN_USERNAME_REGEX.sub('', value)
-
     @classmethod
     def allowed_to_disconnect(cls, user, backend_name, association_id=None):
         """Return if it's safe to disconnect the social account for the
