@@ -7,6 +7,7 @@ import six
 from social.utils import setting_name, module_member
 from social.store import OpenIdStore, OpenIdSessionWrapper
 from social.pipeline import DEFAULT_AUTH_PIPELINE, DEFAULT_DISCONNECT_PIPELINE
+from social.pipeline.utils import partial_from_session, partial_to_session
 
 
 class BaseTemplateStrategy(object):
@@ -33,19 +34,18 @@ class BaseStrategy(object):
     ALLOWED_CHARS = 'abcdefghijklmnopqrstuvwxyz' \
                     'ABCDEFGHIJKLMNOPQRSTUVWXYZ' \
                     '0123456789'
+    # well-known serializable types
+    SERIALIZABLE_TYPES = (dict, list, tuple, set, bool, type(None)) + \
+                         six.integer_types + six.string_types + \
+                         (six.text_type, six.binary_type,)
+    DEFAULT_TEMPLATE_STRATEGY = BaseTemplateStrategy
 
-    def __init__(self, backend=None, storage=None, request=None,
-                 tpl=BaseTemplateStrategy, backends=None, *args, **kwargs):
-        self.tpl = tpl(self)
-        self.request = request
+    def __init__(self, storage=None, tpl=None):
         self.storage = storage
-        self.backends = backends
-        self.backend = backend(strategy=self, *args, **kwargs) \
-                            if backend else None
+        self.tpl = (tpl or self.DEFAULT_TEMPLATE_STRATEGY)(self)
 
     def setting(self, name, default=None, backend=None):
         names = [setting_name(name), name]
-        backend = backend or getattr(self, 'backend', None)
         if backend:
             names.insert(0, setting_name(backend.name, name))
         for name in names:
@@ -55,32 +55,6 @@ class BaseStrategy(object):
                 pass
         return default
 
-    def start(self):
-        # Clean any partial pipeline info before starting the process
-        self.clean_partial_pipeline()
-        if self.backend.uses_redirect():
-            return self.redirect(self.backend.auth_url())
-        else:
-            return self.html(self.backend.auth_html())
-
-    def complete(self, *args, **kwargs):
-        return self.backend.auth_complete(*args, **kwargs)
-
-    def continue_pipeline(self, *args, **kwargs):
-        return self.backend.continue_pipeline(*args, **kwargs)
-
-    def disconnect(self, user, association_id=None, *args, **kwargs):
-        return self.backend.disconnect(
-            user=user, association_id=association_id,
-            *args, **kwargs
-        )
-
-    def authenticate(self, *args, **kwargs):
-        kwargs['strategy'] = self
-        kwargs['storage'] = self.storage
-        kwargs['backend'] = self.backend
-        return self.backend.authenticate(*args, **kwargs)
-
     def create_user(self, *args, **kwargs):
         return self.storage.user.create_user(*args, **kwargs)
 
@@ -114,53 +88,11 @@ class BaseStrategy(object):
         return val
 
     def partial_to_session(self, next, backend, request=None, *args, **kwargs):
-        user = kwargs.get('user')
-        social = kwargs.get('social')
-        clean_kwargs = {
-            'response': kwargs.get('response') or {},
-            'details': kwargs.get('details') or {},
-            'username': kwargs.get('username'),
-            'uid': kwargs.get('uid'),
-            'is_new': kwargs.get('is_new') or False,
-            'new_association': kwargs.get('new_association') or False,
-            'user': user and user.id or None,
-            'social': social and {
-                'provider': social.provider,
-                'uid': social.uid
-            } or None
-        }
-        # Only allow well-known serializable types
-        types = (dict, list, tuple, set) + six.integer_types + \
-                six.string_types + (six.text_type,) + (six.binary_type,)
-        clean_kwargs.update((name, value) for name, value in kwargs.items()
-                                if isinstance(value, types))
-        # Clean any MergeDict data type from the values
-        clean_kwargs.update((name, dict(value))
-                                for name, value in clean_kwargs.items()
-                                    if isinstance(value, dict))
-        return {
-            'next': next,
-            'backend': backend.name,
-            'args': tuple(map(self.to_session_value, args)),
-            'kwargs': dict((key, self.to_session_value(val))
-                                for key, val in clean_kwargs.items())
-        }
+        return partial_to_session(self, next, backend, request=request,
+                                  *args, **kwargs)
 
     def partial_from_session(self, session):
-        kwargs = session['kwargs'].copy()
-        user = kwargs.get('user')
-        social = kwargs.get('social')
-        if isinstance(social, dict):
-            kwargs['social'] = self.storage.user.get_social_auth(**social)
-        if user:
-            kwargs['user'] = self.storage.user.get_user(user)
-        return (
-            session['next'],
-            session['backend'],
-            list(map(self.from_session_value, session['args'])),
-            dict((key, self.from_session_value(val))
-                    for key, val in kwargs.items())
-        )
+        return partial_from_session(self, session)
 
     def clean_partial_pipeline(self, name='partial_pipeline'):
         self.session_pop(name)
@@ -194,11 +126,11 @@ class BaseStrategy(object):
         """Return current language"""
         return ''
 
-    def send_email_validation(self, email):
+    def send_email_validation(self, backend, email):
         email_validation = self.setting('EMAIL_VALIDATION_FUNCTION')
         send_email = module_member(email_validation)
         code = self.storage.code.make_code(email)
-        send_email(self, code)
+        send_email(self, backend, code)
         return code
 
     def validate_email(self, email, code):
@@ -213,6 +145,18 @@ class BaseStrategy(object):
         """Render given template or raw html with given context"""
         return self.tpl.render(tpl, html, context)
 
+    def authenticate(self, backend, *args, **kwargs):
+        """Trigger the authentication mechanism tied to the current
+        framework"""
+        kwargs['strategy'] = self
+        kwargs['storage'] = self.storage
+        kwargs['backend'] = backend
+        return backend.authenticate(*args, **kwargs)
+
+    def get_backends(self):
+        """Return configured backends"""
+        return self.setting('AUTHENTICATION_BACKENDS', [])
+
     # Implement the following methods on strategies sub-classes
 
     def redirect(self, url):
